translate.storage.poxliff

Package translate :: Package storage :: Module poxliff |
[hide private]
[frames] | no frames]

# Module poxliff

source code

XLIFF classes specifically suited for handling the PO representation in XLIFF.

This way the API supports plurals as if it was a PO file, for example.

Classes | [hide private]
| PoXliffUnit A class to specifically handle the plural units created from a po file.
| PoXliffFile a file for the po variant of Xliff files

Functions | [hide private]
hasplurals(thing) | source code

Imports: etree, re, multistring, base, lisa, poheader, xliff, general